==> nocc-1.9.5.txz: usr/local/www/nocc/lang/oc.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: oc.php 2623 2014-10-06 10:07:46Z siebrand $
 */
/** Occitan (occitan)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cedric31
 */

$lang_locale = 'oc_OC.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Avètz pas picat cap de login';
$err_passwd_empty = 'Avètz pas picat cap de senhal';
$alt_delete = 'Escafar los messatges seleccionats';
$alt_delete_one = 'Escafar lo messatge';
$alt_new_msg = 'Messatges novèls';
$alt_reply = 'Respondre a l\'autor';
$alt_reply_all = 'Respondre a totes';
$alt_forward = 'Transferir';
$alt_next = 'Seguent';
$alt_prev = 'Precedent';
$title_next_page = 'Pagina seguenta';
$title_prev_page = 'Pagina precedenta';
$title_next_msg = 'Messatge seguent';
$title_prev_msg = 'Messatge precedent';
$html_theme_label = 'Tèma :';
$html_welcome = 'Benvenguda a %1$s';
$html_login = 'Se connectar';
$html_user_label = 'Utilizaire :';
$html_passwd_label = 'Senhal :';
$html_submit = 'Validar';
$html_help = 'Ajuda';
$html_server_label = 'Servidor :';
$html_wrong = 'L\'identificant o lo senhal son pas valids';
$html_retry = 'Tornar ensajar';
$html_remember = 'Conservar los paramètres';
$html_lang_label = 'Lenga :';
$html_msgperpage_label = 'Messatges per pagina :';
$html_preferences = 'Preferéncias';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adreça electronica :';
$html_bccself = 'Recebre una còpia amagada';
$html_hide_addresses = 'Amagar las adreças electronicas';
$html_outlook_quoting = 'Citacion a la Outlook';
$html_reply_to = 'Respondre a';
$html_reply_to_label = 'Respondre a :';
$html_use_signature = 'Utilizar la signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura :';
$html_reply_leadin_label = 'Entèsta de responsa :';
$html_prefs_updated = 'Preferéncias mesas a jorn';
$html_manage_folders_link = 'Gestion dels dorsièrs IMAP';
$html_manage_filters_link = 'Gestion dels filtres e-mail';
$html_use_graphical_smilies = 'Utilizar las emoticònas graficas';
$html_sent_folder_label = 'Copiar los elements mandats dins un dorsièr dedicat :';
$html_trash_folder_label = 'Desplaçar los elements escafats dins un dorsièr dedicat :';
$html_colored_quotes = 'Citacions coloradas';
$html_display_struct = 'Afichar lo tèxte estructurat';
$html_send_html_mail = 'Mandar los e-mails al format HTML';
$html_folders = 'Dorsièrs';
$html_folders_create_failed = 'Lo dorsièr a pas pogut èsser creat !';
$html_folders_sub_failed = 'Es pas estat possible de s\'inscriure al dorsièr !';
$html_folders_unsub_failed = 'Es pas estat possible de se desinscriure de dorsièr !';
$html_folders_rename_failed = 'Lo dorsièr a pas pogut èsser renomenat !';
$html_folders_updated = 'Dorsièrs meses a jorn';
$html_folder_subscribe = 'S\'inscriure a';
$html_folder_rename = 'Tornar nomenar';
$html_folder_create = 'Crear un dorsièr novèl';
$html_folder_remove = 'Se desinscriure de';
$html_folder_delete = 'Suprimir';
$html_folder_to = 'cap a';
$html_filter_remove = 'Suprimir';
$html_filter_body = 'Còs del messatge';
$html_filter_subject = 'Objècte';
$html_filter_to = 'A';
$html_filter_cc = 'Cc';
$html_filter_from = 'De';
$html_filter_change_tip = 'Per cambiar un filtre, tornatz escriure dessús.';
$html_reapply_filters = 'Tornar aplicar totes los filtres';
$html_filter_contains = 'conten';
$html_filter_name = 'Nom del filtre';
$html_filter_action = 'Accion';
$html_filter_moveto = 'Desplaçar cap a';
$html_select_one = '--Seleccionar--';
$html_and = 'E';
$html_new_msg_in = 'Messatges novèls dins';
$html_or = 'o';
$html_move = 'Desplaçar';
$html_copy = 'Copiar';
$html_messages_to = 'lo messatge seleccionat cap a';
$html_gotopage = 'Anar a la pagina';
$html_gotofolder = 'Anar al dorsièr';
$html_other_folders = 'lo messatge seleccionat cap a';
$html_page = 'Pagina';
$html_of = 'sus';
$html_view_header = 'Veire l\'entèsta';
$html_remove_header = 'Amagar l\'entèsta';
$html_inbox = 'Bóstia de recepcion';
$html_new_msg = 'Escriure';
$html_reply = 'Respondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Respondre a totes';
$html_forward = 'Transferir';
$html_forward_short = 'Tr :';
$html_forward_info = 'Lo messatge transferit serà mandat en pèça junta amb aqueste messatge.';
$html_delete = 'Suprimir';
$html_new = 'Novèl';
$html_mark = 'Escafar';
$html_att_label = 'Pèça junta :';
$html_atts_label = 'Pèças juntas :';
$html_unknown = '[desconegut]';
$html_part_x = 'Partida %s';
$html_attach = 'Estacar';
$html_attach_forget = 'Vos cal estacar vòstre fichièr abans de mandar vòstre messatge !';
$html_attach_delete = 'Suprimir los fichièrs seleccionats';
$html_attach_none = 'Vos cal seleccionar un fichièr d\'estacar !';
$html_sort_by = 'Triar per';
$html_sort = 'Triar';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Subjècte';
$html_subject_label = 'Subjècte :';
$html_date = 'Data';
$html_date_label = 'Data :';
$html_sent_label = 'Mandat lo :';
$html_wrote = 'a escrich';
$html_quote_wrote = 'Lo %1$s a %2$s, %3$s a escrich :';
$html_size = 'Talha';
$html_totalsize = 'Talha totala';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichièr';
$html_to = 'A';
$html_to_label = 'A :';
$html_cc = 'Còpia';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Còpia amagada :';
$html_nosubject = 'Pas cap de subjècte';
$html_send = 'Mandar';
$html_cancel = 'Anullar';
$html_no_mail = 'Pas cap de messatge.';
$html_logout = 'Desconnexion';
$html_msg = 'Messatge';
$html_msgs = 'Messatges';
$html_configuration = 'Lo servidor es pas configurat corrèctament';
$html_priority = 'Prioritat';
$html_priority_label = 'Prioritat :';
$html_lowest = 'Minimala';
$html_low = 'Baissa';
$html_normal = 'Normala';
$html_high = 'Nauta';
$html_highest = 'Maximala';
$html_flagged = 'Marcat';
$html_spam = 'Spam';
$html_spam_warning = 'Aqueste messatge es estat classat coma spam.';
$html_receipt = 'Acusat de recepcion';
$html_select = 'Seleccionar';
$html_select_all = 'Inversar la seleccion';
$html_select_contacts = 'Seleccionar dels contactes';
$html_loading_image = 'Cargament de l\'imatge';
$html_send_confirmed = 'Vòstre messatge es estat mandat';
$html_no_sendaction = 'Cap d\'accion pas especificada. Ensajatz d\'activar JavaScript.';
$html_error_occurred = 'I a agut una error';
$html_prefs_file_error = 'Impossible de dobrir lo fichièr de preferéncias';
$html_wrap = 'Troncar los messatges que sortisson a :';
$html_wrap_none = 'Pas de troncadura';
$html_usenet_separator = 'Separator Usenet ("-- \n") abans la signatura';
$html_mark_as = 'Marcar coma';
$html_read = 'legit';
$html_unread = 'pas legit';
$html_encoding_label = 'Encodatge del tèxte :';
$html_add = 'Apondre';
$html_contacts = 'Contactes de %1$s';
$html_modify = 'Mdificar';
$html_back = 'Retorn';
$html_contact_add = 'Apondre un contacte novèl';
$html_contact_mod = 'Modificar un contacte';
$html_contact_first = 'Pichon nom';
$html_contact_last = 'Nom d\'Ostal';
$html_contact_nick = 'Escais';
$html_contact_mail = 'Adreça electronica';
$html_contact_list = 'Lista de contactes de %1$s';
$html_contact_del = 'de la lista de contactes';
$html_contact_count = '%1$d contactes';
$html_contact_err1 = 'Lo nombre maximal de contactes es « %1$d »';
$html_contact_err2 = 'Podètz pas apondre un contacte novèl';
$html_contact_err3 = 'Avètz pas lo drech d\'accedir a la lista de contactes';
$html_contact_none = 'Cap de contacte es pas estat trobat';
$html_del_msg = 'Suprimir lo(s) messatge(s) seleccionat(s) ?';
$html_down_mail = 'Telecargar';
$original_msg = '-- Messatge original --';
$to_empty = 'Lo camp \'A\' deu pas èsser void !';
$html_images_warning = 'Per vòstra seguretat, los imatges distants son desactivats.';
$html_images_display = 'Afichar los imatges';
$html_smtp_error_no_conn = 'Impossible de dobrir la connexion';
$html_smtp_error_unexpected = 'Responsa inesperada :';
$lang_could_not_connect = 'Impossible de se connectar al servidor';
$lang_invalid_msg_num = 'Marrit numèro de messatge';
$html_file_upload_attack = 'Possibilitat d\'atac dempuèi lo fichièr telecargat';
$html_invalid_email_address = 'Adreça electronica invalida';
$html_invalid_msg_per_page = 'Nombre de messatges per pagina invalid';
$html_invalid_wrap_msg = 'Valor d\'apondon de messatge invalida';
$html_seperate_msg_win = 'Messatges dins de fenètras separadas';
$html_err_file_contacts = 'Impossible de dobrir lo fichièr dels contactes';
$html_session_file_error = 'Impossible de dobrir lo fichièr de las sesilhas';
$html_login_not_allowed = 'Aqueste identificant es pas autorizat a se connectar.';
$lang_err_send_delay = 'Vos cal esperar entre dos messatges (%1$d segondas)';
$html_search = 'Recercar';
$html_new_session = 'Sesilha venenta';
$html_fd_filename = 'Telecargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=I a pas cap de corrièr electronic|1=I a %1$d corrièr electronic|I a %1$d corrièrs electronics}} dins lo dorsièr.';
$html_fd_filesize = 'talha %1$d';
$html_fd_skipcount = 'amb %1$d corrièrs electronics';
$reset_clicked = 'Sètz segur que volètz voidar aqueste formulari ?';
$html_send_recover = 'Connexion per recuperar lo borrolhon perdut !';
$html_send_discard = 'Clicar aicí per ignorar lo borrolhon enregistrat.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/oc.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: oc.php 2665 2016-06-22 14:49:54Z siebrand $
 */
/** Occitan (occitan)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cedric31
 */

$lang_locale = 'oc_OC.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Avètz pas picat cap de login';
$err_passwd_empty = 'Avètz pas picat cap de senhal';
$alt_delete = 'Escafar los messatges seleccionats';
$alt_delete_one = 'Escafar lo messatge';
$alt_new_msg = 'Messatges novèls';
$alt_reply = 'Respondre a l\'autor';
$alt_reply_all = 'Respondre a totes';
$alt_forward = 'Transferir';
$alt_next = 'Seguent';
$alt_prev = 'Precedent';
$title_next_page = 'Pagina seguenta';
$title_prev_page = 'Pagina precedenta';
$title_next_msg = 'Messatge seguent';
$title_prev_msg = 'Messatge precedent';
$html_theme_label = 'Tèma :';
$html_welcome = 'Benvenguda a %1$s';
$html_login = 'Se connectar';
$html_user_label = 'Utilizaire :';
$html_passwd_label = 'Senhal :';
$html_submit = 'Validar';
$html_help = 'Ajuda';
$html_server_label = 'Servidor :';
$html_wrong = 'L\'identificant o lo senhal son pas valids';
$html_retry = 'Tornar ensajar';
$html_remember = 'Conservar los paramètres';
$html_lang_label = 'Lenga :';
$html_msgperpage_label = 'Messatges per pagina :';
$html_preferences = 'Preferéncias';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adreça electronica :';
$html_bccself = 'Recebre una còpia amagada';
$html_hide_addresses = 'Amagar las adreças electronicas';
$html_outlook_quoting = 'Citacion a la Outlook';
$html_reply_to = 'Respondre a';
$html_reply_to_label = 'Respondre a :';
$html_use_signature = 'Utilizar la signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura :';
$html_reply_leadin_label = 'Entèsta de responsa :';
$html_prefs_updated = 'Preferéncias mesas a jorn';
$html_manage_folders_link = 'Gestion dels dorsièrs IMAP';
$html_manage_filters_link = 'Gestion dels filtres e-mail';
$html_use_graphical_smilies = 'Utilizar las emoticònas graficas';
$html_sent_folder_label = 'Copiar los elements mandats dins un dorsièr dedicat :';
$html_trash_folder_label = 'Desplaçar los elements escafats dins un dorsièr dedicat :';
$html_colored_quotes = 'Citacions coloradas';
$html_display_struct = 'Afichar lo tèxte estructurat';
$html_send_html_mail = 'Mandar los e-mails al format HTML';
$html_folders = 'Dorsièrs';
$html_folders_create_failed = 'Lo dorsièr a pas pogut èsser creat !';
$html_folders_sub_failed = 'Es pas estat possible de s\'inscriure al dorsièr !';
$html_folders_unsub_failed = 'Es pas estat possible de se desinscriure de dorsièr !';
$html_folders_rename_failed = 'Lo dorsièr a pas pogut èsser renomenat !';
$html_folders_updated = 'Dorsièrs meses a jorn';
$html_folder_subscribe = 'S\'inscriure a';
$html_folder_rename = 'Tornar nomenar';
$html_folder_create = 'Crear un dorsièr novèl';
$html_folder_remove = 'Se desinscriure de';
$html_folder_delete = 'Suprimir';
$html_folder_to = 'cap a';
$html_filter_remove = 'Suprimir';
$html_filter_body = 'Còs del messatge';
$html_filter_subject = 'Objècte';
$html_filter_to = 'A';
$html_filter_cc = 'Cc';
$html_filter_from = 'De';
$html_filter_change_tip = 'Per cambiar un filtre, tornatz escriure dessús.';
$html_reapply_filters = 'Tornar aplicar totes los filtres';
$html_filter_contains = 'conten';
$html_filter_name = 'Nom del filtre';
$html_filter_action = 'Accion';
$html_filter_moveto = 'Desplaçar cap a';
$html_select_one = '--Seleccionar--';
$html_and = 'E';
$html_new_msg_in = 'Messatges novèls dins';
$html_or = 'o';
$html_move = 'Desplaçar';
$html_copy = 'Copiar';
$html_messages_to = 'lo messatge seleccionat cap a';
$html_gotopage = 'Anar a la pagina';
$html_gotofolder = 'Anar al dorsièr';
$html_other_folders = 'lo messatge seleccionat cap a';
$html_page = 'Pagina';
$html_of = 'sus';
$html_view_header = 'Veire l\'entèsta';
$html_remove_header = 'Amagar l\'entèsta';
$html_inbox = 'Bóstia de recepcion';
$html_new_msg = 'Escriure';
$html_reply = 'Respondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Respondre a totes';
$html_forward = 'Transferir';
$html_forward_short = 'Tr :';
$html_forward_info = 'Lo messatge transferit serà mandat en pèça junta amb aqueste messatge.';
$html_delete = 'Suprimir';
$html_new = 'Novèl';
$html_mark = 'Escafar';
$html_att_label = 'Pèça junta :';
$html_atts_label = 'Pèças juntas :';
$html_unknown = '[desconegut]';
$html_part_x = 'Partida %s';
$html_attach = 'Estacar';
$html_attach_forget = 'Vos cal estacar vòstre fichièr abans de mandar vòstre messatge !';
$html_attach_delete = 'Suprimir los fichièrs seleccionats';
$html_attach_none = 'Vos cal seleccionar un fichièr d\'estacar !';
$html_sort_by = 'Triar per';
$html_sort = 'Triar';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Subjècte';
$html_subject_label = 'Subjècte :';
$html_date = 'Data';
$html_date_label = 'Data :';
$html_sent_label = 'Mandat lo :';
$html_wrote = 'a escrit';
$html_quote_wrote = 'Lo %1$s a %2$s, %3$s a escrit :';
$html_size = 'Talha';
$html_totalsize = 'Talha totala';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichièr';
$html_to = 'A';
$html_to_label = 'A :';
$html_cc = 'Còpia';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Còpia amagada :';
$html_nosubject = 'Pas cap de subjècte';
$html_send = 'Mandar';
$html_cancel = 'Anullar';
$html_no_mail = 'Pas cap de messatge.';
$html_logout = 'Desconnexion';
$html_msg = 'Messatge';
$html_msgs = 'Messatges';
$html_configuration = 'Lo servidor es pas configurat corrèctament';
$html_priority = 'Prioritat';
$html_priority_label = 'Prioritat :';
$html_lowest = 'Minimala';
$html_low = 'Baissa';
$html_normal = 'Normala';
$html_high = 'Nauta';
$html_highest = 'Maximala';
$html_flagged = 'Marcat';
$html_spam = 'Spam';
$html_spam_warning = 'Aqueste messatge es estat classat coma spam.';
$html_receipt = 'Acusat de recepcion';
$html_select = 'Seleccionar';
$html_select_all = 'Inversar la seleccion';
$html_select_contacts = 'Seleccionar dels contactes';
$html_loading_image = 'Cargament de l\'imatge';
$html_send_confirmed = 'Vòstre messatge es estat mandat';
$html_no_sendaction = 'Cap d\'accion pas especificada. Ensajatz d\'activar JavaScript.';
$html_error_occurred = 'I a agut una error';
$html_prefs_file_error = 'Impossible de dobrir lo fichièr de preferéncias';
$html_wrap = 'Troncar los messatges que sortisson a :';
$html_wrap_none = 'Pas de troncadura';
$html_usenet_separator = 'Separator Usenet ("-- \n") abans la signatura';
$html_mark_as = 'Marcar coma';
$html_read = 'legit';
$html_unread = 'pas legit';
$html_encoding_label = 'Encodatge del tèxte :';
$html_add = 'Apondre';
$html_contacts = 'Contactes de %1$s';
$html_modify = 'Mdificar';
$html_back = 'Retorn';
$html_contact_add = 'Apondre un contacte novèl';
$html_contact_mod = 'Modificar un contacte';
$html_contact_first = 'Pichon nom';
$html_contact_last = 'Nom d\'Ostal';
$html_contact_nick = 'Escais';
$html_contact_mail = 'Adreça electronica';
$html_contact_list = 'Lista de contactes de %1$s';
$html_contact_del = 'de la lista de contactes';
$html_contact_count = '%1$d contactes';
$html_contact_err1 = 'Lo nombre maximal de contactes es « %1$d »';
$html_contact_err2 = 'Podètz pas apondre un contacte novèl';
$html_contact_err3 = 'Avètz pas lo dreit d\'accedir a la lista de contactes';
$html_contact_none = 'Cap de contacte es pas estat trobat';
$html_contact_ruler_top = 'Naut';
$html_contact_listcheck_title = 'Marcar d\'una crotz per apondre lo corrièr a la lista.';
$html_contact_list_add = 'Apondre a la lista';
$html_contact_listname = 'Nom de la lista';
$html_contact_listonly = 'Listas unicament';
$html_contact_all = 'Afichar tot';
$html_contact_add_confirm = 'Apondre los corrièrs electronics a la lista existenta ?';
$html_del_msg = 'Suprimir lo(s) messatge(s) seleccionat(s) ?';
$html_down_mail = 'Telecargar';
$original_msg = '-- Messatge original --';
$to_empty = 'Lo camp \'A\' deu pas èsser void !';
$html_images_warning = 'Per vòstra seguretat, los imatges distants son desactivats.';
$html_images_display = 'Afichar los imatges';
$html_smtp_error_no_conn = 'Impossible de dobrir la connexion';
$html_smtp_error_unexpected = 'Responsa inesperada :';
$lang_could_not_connect = 'Impossible de se connectar al servidor';
$lang_invalid_msg_num = 'Marrit numèro de messatge';
$html_file_upload_attack = 'Possibilitat d\'atac dempuèi lo fichièr telecargat';
$html_invalid_email_address = 'Adreça electronica invalida';
$html_invalid_msg_per_page = 'Nombre de messatges per pagina invalid';
$html_invalid_wrap_msg = 'Valor d\'apondon de messatge invalida';
$html_seperate_msg_win = 'Messatges dins de fenètras separadas';
$html_err_file_contacts = 'Impossible de dobrir lo fichièr dels contactes';
$html_session_file_error = 'Impossible de dobrir lo fichièr de las sessions';
$html_login_not_allowed = 'Aqueste identificant es pas autorizat a se connectar.';
$lang_err_send_delay = 'Vos cal esperar entre dos messatges (%1$d segondas)';
$html_search = 'Recercar';
$html_new_session = 'Session venenta';
$html_fd_filename = 'Telecargar %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=I a pas cap de corrièr electronic|1=I a %1$d corrièr electronic|I a %1$d corrièrs electronics}} dins lo dorsièr.';
$html_fd_mailskip = 'Los corrièls seguents faràn pas partida del fichièr mbox, perque depassan la valor de memory_limit de PHP :';
$html_fd_filesize = 'talha %1$d';
$html_fd_skipcount = 'amb %1$d corrièrs electronics';
$html_fd_largefolder = 'Segon vòstra velocitat de telecargament, aqueste telecargament pòt fracassar a causa d’un depassament de durada de l\'escript.<br />Verificatz la completud de vòstre telecargament o fixatz max_execution_time a una valor superiora dins php.ini.';
$reset_clicked = 'Sètz segur que volètz voidar aqueste formulari ?';
$html_send_recover = 'Connexion per recuperar lo borrolhon perdut !';
$html_send_discard = 'Clicar aicí per ignorar lo borrolhon enregistrat.';
$html_collect_label = 'Collectar automaticament las adreças de corrièr electronic :';
$html_collect_option0 = 'Pas jamai';
$html_collect_option1 = 'Solament pels corrièls sortents';
$html_collect_option2 = 'Solament pels corrièls dobèrts';
$html_collect_option3 = 'Totjorn';
